ProtobufCodec
This codec converts Ledger API GRPC values.
Attributes
- Graph
-
- Supertypes
Members list
Type members
Inherited types
Final result type
Final result type
Attributes
- Inherited from:
- WithResult
Value members
Concrete methods
Boolean
Boolean
Attributes
- Definition Classes
-
SchemaVisitor
Contract ID, parametrized with the processor for corresponding template
Contract ID, parametrized with the processor for corresponding template
Attributes
- Definition Classes
-
SchemaVisitor
Date
Date
Attributes
- Definition Classes
-
SchemaVisitor
ADT, Sum type - special case, where there are only named constructors without arguments
ADT, Sum type - special case, where there are only named constructors without arguments
Attributes
- Definition Classes
-
SchemaVisitor
Map with keys and values of any type
Map with keys and values of any type
Attributes
- Definition Classes
-
SchemaVisitor
8-byte Integer
8-byte Integer
Attributes
- Definition Classes
-
SchemaVisitor
Sequence of elements
Sequence of elements
Attributes
- Definition Classes
-
SchemaVisitor
Numeric with scale
Numeric with scale
Attributes
- Definition Classes
-
SchemaVisitor
Optional element
Optional element
Attributes
- Definition Classes
-
SchemaVisitor
Party
Party
Attributes
- Definition Classes
-
SchemaVisitor
ADT, Product type
ADT, Product type
Attributes
- Definition Classes
-
SchemaVisitor
Text
Text
Attributes
- Definition Classes
-
SchemaVisitor
Map with keys of String/Text type
Map with keys of String/Text type
Attributes
- Definition Classes
-
SchemaVisitor
Timestamp
Timestamp
Attributes
- Definition Classes
-
SchemaVisitor
Unit
Unit
Attributes
- Definition Classes
-
SchemaVisitor
ADT, Sum type
ADT, Sum type
Attributes
- Definition Classes
-
SchemaVisitor
Inherited methods
Type Application
Type Application
Attributes
- Definition Classes
-
CodecVisitor -> SchemaVisitor
- Inherited from:
- CodecVisitor
Attributes
- Definition Classes
-
CodecVisitor -> SchemaVisitor
- Inherited from:
- CodecVisitor
Wrap type into addressable DataType
Wrap type into addressable DataType
Attributes
- Definition Classes
-
CodecVisitor -> SchemaVisitor
- Inherited from:
- CodecVisitor
Type Variable.
Type Variable.
Codecs will use substitution, effectively replacing type variables with concrete types, while code generators will use type variable names.
Attributes
- Definition Classes
-
CodecVisitor -> SchemaVisitor
- Inherited from:
- CodecVisitor